==> fishersapi-0.1.3-py3-none-any.whl: fishersapi/version.py <==
from __future__ import absolute_import, division, print_function
from os import path

# Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
_version_major = 0
_version_minor = 1
_version_micro = 3  # use '' for first of series, number for 1 and above
#_version_extra = 'dev'
_version_extra = ''  # Uncomment this for full releases

# Construct full version string from these.
_ver = [_version_major, _version_minor]
if _version_micro:
    _ver.append(_version_micro)
if _version_extra:
    _ver.append(_version_extra)

__version__ = '.'.join(map(str, _ver))

CLASSIFIERS = ["Development Status :: 3 - Alpha",
               "Environment :: Console",
               "Intended Audience :: Science/Research",
               "License :: OSI Approved :: MIT License",
               "Operating System :: OS Independent",
               "Programming Language :: Python",
               "Topic :: Scientific/Engineering"]

# Description should be a one-liner:
description = "fishersapi: An API for applying a fast Fisher's Exact Test to variable pairs in pandas DataFrames"

NAME = "fishersapi"
MAINTAINER = "Andrew Fiore-Gartland"
MAINTAINER_EMAIL = "agartlan@fredhutch.org"
DESCRIPTION = description
URL = "http://github.com/agartland/fishersapi"
DOWNLOAD_URL = ""
LICENSE = "MIT"
AUTHOR = "Andrew Fiore-Gartland"
AUTHOR_EMAIL = "agartlan@fredhutch.org"
PLATFORMS = "OS Independent"
MAJOR = _version_major
MINOR = _version_minor
MICRO = _version_micro
VERSION = __version__
PACKAGE_DATA = {}
REQUIRES = ['numpy', 'scipy', 'pandas', 'fisher', 'statsmodels']

==> fishersapi-0.3-py3-none-any.whl: fishersapi/version.py <==
from __future__ import absolute_import, division, print_function
from os import path

# Format expected by setup.py and doc/source/conf.py: string of form "X.Y.Z"
_version_major = 0
_version_minor = 3
_version_micro = ''  # use '' for first of series, number for 1 and above

#_version_extra = 'dev'
_version_extra = ''  # Uncomment this for full releases

# Construct full version string from these.
_ver = [_version_major, _version_minor]
if _version_micro:
    _ver.append(_version_micro)
if _version_extra:
    _ver.append(_version_extra)

__version__ = '.'.join(map(str, _ver))

CLASSIFIERS = ["Development Status :: 3 - Alpha",
               "Environment :: Console",
               "Intended Audience :: Science/Research",
               "License :: OSI Approved :: MIT License",
               "Operating System :: OS Independent",
               "Programming Language :: Python",
               "Topic :: Scientific/Engineering"]

# Description should be a one-liner:
description = "fishersapi: An API for applying a fast Fisher's Exact Test to variable pairs in pandas DataFrames"

NAME = "fishersapi"
MAINTAINER = "Andrew Fiore-Gartland"
MAINTAINER_EMAIL = "agartlan@fredhutch.org"
DESCRIPTION = description
URL = "http://github.com/agartland/fishersapi"
DOWNLOAD_URL = ""
LICENSE = "MIT"
AUTHOR = "Andrew Fiore-Gartland"
AUTHOR_EMAIL = "agartlan@fredhutch.org"
PLATFORMS = "OS Independent"
MAJOR = _version_major
MINOR = _version_minor
MICRO = _version_micro
VERSION = __version__
PACKAGE_DATA = {}
REQUIRES = ['numpy', 'scipy', 'pandas', 'fisher', 'statsmodels']
